pub struct Priority(/* private fields */);Expand description
Packed Facility-Priority bit field.
Implementations
Sourceimpl Priority
impl Priority
pub const Emerg: Self
pub const Alert: Self
pub const Crit: Self
pub const Err: Self
pub const Warn: Self
pub const Notice: Self
pub const Info: Self
pub const Debug: Self
pub const UpToEmerg: Self
pub const UpToAlert: Self
pub const UpToCrit: Self
pub const UpToErr: Self
pub const UpToWarn: Self
pub const UpToNotice: Self
pub const UpToInfo: Self
pub const UpToDebug: Self
pub const Kern: Self
pub const User: Self
pub const Mail: Self
pub const Daemon: Self
pub const Auth: Self
pub const Syslog: Self
pub const Printer: Self
pub const News: Self
pub const UUCP: Self
pub const CRON: Self
pub const AuthPriv: Self
pub const FTP: Self
pub const Local0: Self
pub const Local1: Self
pub const Local2: Self
pub const Local3: Self
pub const Local4: Self
pub const Local5: Self
pub const Local6: Self
pub const Local7: Self
pub const FacilityMask: Self
pub const PriorityMask: Self
Sourceimpl Priority
impl Priority
Sourcepub const fn bits(&self) -> c_int
pub const fn bits(&self) -> c_int
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: c_int) -> Option<Self>
pub const fn from_bits(bits: c_int) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: c_int) -> Self
pub const fn from_bits_truncate(bits: c_int) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: c_int) -> Self
pub const fn from_bits_retain(bits: c_int) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl Priority
impl Priority
Sourcepub const fn iter(&self) -> Iter<Priority>
pub const fn iter(&self) -> Iter<Priority>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Priority>
pub const fn iter_names(&self) -> IterNames<Priority>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl Priority
impl Priority
Sourcepub fn with_facility(self, facility: c_int) -> Option<Self>
pub fn with_facility(self, facility: c_int) -> Option<Self>
Keep mask but replace facility.
Sourcepub fn should_log(self, priority: Self) -> bool
pub fn should_log(self, priority: Self) -> bool
Returns if a message of priority should be retained by this mask.